	#pragma rtGlobals=3		// Use modern global access method and strict wave access.
	
	
	// This macro is used to concatenate (put together) 2 images of an IODP section. When 2 images are present for a single section, the macro assumes
	//	that the first image is designated with a "-1.jpg" at the end and the second image has a "-2.jpg". The macro further assumes the the first image
	//	has been cropped to 140 cm.
	// In the case where there is only 1 image (the section is shorter than 140 cm), the macro will use only the single image.
	//
	// A section image wave is created and scaled in cm. The section image is also saved to the external image folder with a file name that can be used for the
	//	Core Image Assembly macros.
	
	Macro Assemble_Section_Images(Hole,Core,Type,Section,Filter)
		Variable Core=G_Core, Section=G_Section				//  Core and Section are numeric variables set to global values
		String Type=G_Type, Filter=G_S1, Hole=G_Hole			//  Type, Hole, and the Filter are string variables set to global values
																//		The Filter is a unique identifier of the images to be loaded, like "22X-2"
		Variable i=0, j=0										// i and j are counters
		String Image_File, Coring_Matrix, Section_Image, S1, S2	// Image_File is the string variable assigned to the name of an external image file
																	// Coring_Matrix is the string variable with the name of the coring_matrix
																	// Section_Image is the string assigned the name of the combined section image
		Silent 1						// Suppresses printing to the command line while macro is running
		PauseUpdate				// Stops graphs and tables from updating until the macro is finshed
		NewPath/O IMAGE_PATH 	// Sets a path to the folder holding the images. A New Path dialog will open each time the macro is run. To avoid
									//	this, run the macro the first time or use the "New Path"dialog under the "Misc"menu to specify the image folder
									// 	 and comment out this line,
		Do
			Image_File=IndexedFile(IMAGE_PATH,i,".jpg")			// This loop picks out the images for the desired Core-Section using the filter.
			If(StringMatch(Image_File,"*"+Filter+"*"))			// IndexedFile loops through all of the jpg's in the image folder using the i counter.
				ImageLoad/O/T=jpeg/P=IMAGE_PATH Image_File	// The Filter checks to see which files need to be loaded and ImageLoad loads them if the
				j+=1												//  filter is matched. j is the counter for the number of images loaded.
			EndIf
			i+=1													// i is the counter for working through the list of files in the folder.
		While(StrLen(Image_File)>2)								// The loop ends when the string "Image_File" is empty - no more files
		If(j==0)
			Abort "No Images Were Loaded  Macro Terminated"		// If j=0, then no files matched the filter and the macro is aborted with a message.
		EndIf
		Coring_Matrix=Hole+"_Coring_Matrix"						// the string "Coring_Matrix" is formed as the name of the proper coring matrix wave
	
		If(Core<10)
			Section_Image=Hole+"_0"+Num2Str(Core)+Type+"_"+Num2Str(Section)		// The name of the combined section image is formed from the 
		Else																				//	Hole, Core, Type, and Section. If the Core number is less than
			Section_Image=Hole+"_"+Num2Str(Core)+Type+"_"+Num2Str(Section)		// 	10 (single digit) then a 0 (zero) is added to the name.
		EndIf																			//	Num2Str() converts numeric variables to strings
	
		If(j==1)																						// If j=1, then only a single image matched the filter.
			Make/B/U/O/N=( ($Coring_Matrix[Core][Section][1]*10000), 100, 3) $Section_Image	// This step makes an empty image that is sized	according
																									// to the core length data in the coring matrix. the
																									// multiplier of 10,000 reflects something close to the
																									// original resolution of the scanned images.
			SetScale/I x 0,($Coring_Matrix[Core][Section][1]*100),"", $Section_Image		// The new section image is scaled in cm (X) and 0 to 1 (Y)
			SetScale/I y 0,1,"", $Section_Image
			SetScale/I x 0,($Coring_Matrix[Core][Section][1]*100),"", $S_FileName			// The image wave that was loaded is scaled the same as the
			SetScale/I y 0,1,"", $S_FileName													//	blank section image. S_FileName is the default name for
																							//	whatever file was last loaded.
			$Section_Image(0,$Coring_Matrix[Core][Section][1]*100)()()=$S_FileName(x)(y)(z)	// The image is copied from the original to the new section image
																								//  Because the copying is done in scaled x,y,z space IGOR 
																								//	automatically adjust for different sizes of the 2 images.
			KillWaves $S_FileName				// The image file that was loaded is killed.
		Else							// If j>1, then 2 images were loaded and need to be combined.
			Make/B/U/O/N=( ($Coring_Matrix[Core][Section][1]*10000), 100, 3) $Section_Image	// A new, empty section image wave is formed as above.
			SetScale/I x 0,$Coring_Matrix[Core][Section][1]*100,"", $Section_Image
			SetScale/I y 0,1,"", $Section_Image
			S1=WaveList("*"+Filter+"*",";","")		// S1 is a list of the filtered waves just loaded, generally ImageX-1.jpg and ImageX-2.jpg
			i=0										// i is the counter for which wave of the S1 list is being processed.
			Do
				S2=StringFromList(i,S1)				// S2 is one of the image waves from the S1 list.
				If(StringMatch(S2,"*1.*"))						// If the image name contains "*1.*" it is the first (long) image and is assumed to be 140 cm
					SetScale/I x 0,140,"", $S2					//	the x dimension is scaled from 0 to 140 cm
					SetScale/I y 0,1,"", $S2						//  	y is scaled from 0 to 1
					$Section_Image(0,140)()()=$S2(x)(y)(z)	// 	The image is copied from the image file to the upper 140 cm of the new section image
					KillWaves $S2								//   The image file wave is killed
				Else									// If the image file wave name does not contain "*1.*" then it must be the second (short) image from 
					SetScale/I x ($Coring_Matrix[Core][Section][1]*100),140,"", $S2	// 140 cm to the bottom of the section. Because the image is the
					SetScale/I y 0,1,"", $S2												// reverse of normal and increases right to left, the image is scaled
					 ImageRotate/V/O $S2												// from the deepest depth to 140 cm. There is a vertical rotation to
					 																	// compensate for the core being reversed while scanning
					$Section_Image(140,$Coring_Matrix[Core][Section][1]*100)()()=$S2(x)(y)(z)	// The image from the second image file wave is copied
																									//	to the new section image
					KillWaves $S2					//	The image file wave is killed
				EndIf	
				i+=1
			While(i<2)			// There are only supposed to be 2 images per section, so the loop only goes twice.
		EndIf
		ImageRotate/O/C/A=90 $Section_Image		// The image is rotated from the horizontal to the vertical to match the orientation of images from the
														//	IODP scanners and be compatible with existing core image assembly macros
		ImageSave/O/P=IMAGE_PATH/T="jpeg" $Section_Image as Section_Image+".jpg"	// An external JPEG image is saved to the image folder
		Display /W=(35,44,194,1212) 			// A window is set to display the new section image
		AppendImage/T $Section_Image		// Image is appended to the window
		SetAxis/A/R left							// The depth axis is reversed so the 0 cm is at the top
		G_Core=Core				// Global variables are reset. Section is incremented by 1 for the next run of the macro.
		G_Section=Section+1
		G_Type=Type
		G_S1=Filter
		G_Hole=Hole
	End	
	
